version property

  1. @TagNumber.new(15)
int get version

Any compliant implementation must first read the version number encoded in this message and choose the correct implementation for this version number before proceeding to decode other parts of this message.

Implementation

@$pb.TagNumber(15)
$core.int get version => $_getI(5, 1);
  1. @TagNumber.new(15)
set version (int value)

Implementation

@$pb.TagNumber(15)
set version($core.int value) => $_setUnsignedInt32(5, value);