raw/raw_vector_tile library

Classes

VectorTile
VectorTile_Feature
Features are described in section 4.2 of the specification
VectorTile_GeomType
GeomType is described in section 4.3.4 of the specification
VectorTile_Layer
Layers are described in section 4.1 of the specification
VectorTile_Value
Variant type encoding The use of values is described in section 4.1 of the specification

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.

Functions

createVectorTile({required List<VectorTile_Layer> layers}) VectorTile
Create a VectorTile instance from a list of layers
createVectorTileFeature({Int64? id, List<int>? tags, required VectorTile_GeomType type, required List<int> geometry}) VectorTile_Feature
Create a feature that will be attach into layers
createVectorTileGeomType({required int type}) VectorTile_GeomType?
Get GeomType for given int value
createVectorTileLayer({required String name, required int extent, required int version, List<String>? keys, List<VectorTile_Value>? values, List<VectorTile_Feature>? features}) VectorTile_Layer
Create a layer that will be attach into vector tiles
createVectorTileValue({String? stringValue, double? floatValue, double? doubleValue, Int64? intValue, Int64? uintValue, Int64? sintValue, bool? boolValue}) VectorTile_Value
Create a value that will be attach into layers