Command class

Command and its utils

Constructors

Command({required int id, required int count})
Command.CommandInteger({required int command})
factory

Properties

count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

zigZagDecode(int parameterInteger) → int
zigZagEncode(int val) → int