VectorTileValue class

Constructors

VectorTileValue({String? stringValue, double? floatValue, double? doubleValue, Int64? intValue, Int64? uintValue, Int64? sintValue, bool? boolValue})
factory
VectorTileValue.from(ValueType type, Object value)
VectorTileValue.fromRaw(VectorTile_Value value)
factory

Properties

boolValue → bool?
no setter
dartBoolValue → bool?
no setter
dartDoubleValue → double?
no setter
dartIntValue → Int64?
no setter
dartStringValue → String?
no setter
doubleValue → double?
no setter
floatValue → double?
no setter
hashCode → int
The hash code for this object.
no setterinherited
intValue → Int64?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sintValue → Int64?
no setter
stringValue → String?
no setter
type → ValueType
final
uintValue → Int64?
no setter
value → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRaw() → VectorTile_Value
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited